# rnadtu

A Python package for running the CIDR algorithm (originally in R) for clustering single-cell RNA-seq data.

## Features
- Can run the CIDR-Algorithm in Python with the "cidr" function on an AnnData-object with either subprocesses or rpy2.

## Installation
```bash
pip install rnadtu
